#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2

# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2023-08-05
# File  : vzlogger.py
#
# vzlogger
#
#
# https://wiki.volkszaehler.org/software/controller/vzlogger
#
# 2023-08-05: initial release

from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Dictionary,
    ListOf,
    TextUnicode,
    Tuple,
    DropdownChoice,
    Integer,
    TextAscii,
)

from cmk.gui.plugins.wato.utils import (
    HostRulespec,
    rulespec_registry,
    RulespecGroupCheckParametersDiscovery,
    CheckParameterRulespecWithItem,
    RulespecGroupCheckParametersApplications,
    Levels,
)


def _parameter_valuespec_vzlogger():
    return Dictionary(
        title=_('vzlogger'),
        elements=[
            ('levels_upper',
             Levels(
                 title=_('Levels (upper)'),
                 help=_('This sets the upper limits for the vzlogger channel.'),
                 unit=_(''),
             )),
            ('levels_lower',
             Tuple(
                 title=_('Levels lower'),
                 help=_('This sets the lower limits for the vzlogger channel. '
                        'This will only be used if "Levels (upper)" is not using Predictive Levels.'
                        ),
                 elements=[
                     Integer(title=_('Warning blow'), minvalue=0, unit=_('')),
                     Integer(title=_('Critical below'), minvalue=0, unit=_('')),
                 ]))

        ],
        optional_keys=False,
    )


rulespec_registry.register(
    CheckParameterRulespecWithItem(
        check_group_name="vzlogger",
        group=RulespecGroupCheckParametersApplications,
        parameter_valuespec=_parameter_valuespec_vzlogger,
        item_spec=lambda: TextAscii(title=_('vzlogger item')),
    ))


def _parameter_valuespec_discovery_vzlogger():
    return Dictionary(
        title=_('vzlogger'),
        elements=[
            ('channels',
             ListOf(
                 Tuple(
                     orientation='horizontal',
                     elements=[
                         TextUnicode(
                             title=_('UUID'),
                             help=_(
                                 'Value must (or better should) match the pattern '
                                 '^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$'
                                 '.'
                             ),
                             allow_empty=False,
                             size=36,
                         ),
                         DropdownChoice(
                             title=_('Channel type'),
                             help=_('Defines what type of counter the channel delivers.'),
                             choices=[
                                 ('meter_reading', 'Meter reading'),
                                 ('voltage', 'Voltage (V)'),
                                 ('electrical_power', 'Electrical Power (W)'),
                             ],
                             sorted=True,
                         ),
                         TextUnicode(
                             title=_('Service name (item)'),
                             help=_('Name of the service in CMK. Must be unique within the channel type.'),
                             allow_empty=False,
                             size=30,
                         ),
                     ]),
                 add_label=_('Add channel'),
                 movable=False,
                 title=_('Channels'),
             )),
        ],
    )


rulespec_registry.register(
    HostRulespec(
        group=RulespecGroupCheckParametersDiscovery,
        match_type='dict',
        name='discovery_vzlogger',
        valuespec=_parameter_valuespec_discovery_vzlogger,
    ))
